package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.EmsFacsAttr;

/**
 * 能源设施/系统属性Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
public interface EmsFacsAttrMapper {
    /**
     * 查询能源设施/系统属性
     *
     * @param id 能源设施/系统属性主键
     * @return 能源设施/系统属性
     */
    EmsFacsAttr selectEmsFacsAttrById(Long id);

    /**
     * 查询能源设施/系统属性列表
     *
     * @param emsFacsAttr 能源设施/系统属性
     * @return 能源设施/系统属性集合
     */
    List<EmsFacsAttr> selectEmsFacsAttrList(EmsFacsAttr emsFacsAttr);

    /**
     * 新增能源设施/系统属性
     *
     * @param emsFacsAttr 能源设施/系统属性
     * @return 结果
     */
    int insertEmsFacsAttr(EmsFacsAttr emsFacsAttr);

    /**
     * 批量新增能源设施/系统属性
     *
     * @param list 能源设施/系统属性
     * @return 结果
     */
    int insertEmsFacsAttrBatch(List<EmsFacsAttr> list);

    /**
     * 修改能源设施/系统属性
     *
     * @param emsFacsAttr 能源设施/系统属性
     * @return 结果
     */
    int updateEmsFacsAttr(EmsFacsAttr emsFacsAttr);

    /**
     * 删除能源设施/系统属性
     *
     * @param id 能源设施/系统属性主键
     * @return 结果
     */
    int deleteEmsFacsAttrById(Long id);

    /**
     * 批量删除能源设施/系统属性
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteEmsFacsAttrByIds(Long[] ids);

    /**
     * 批量删除能源设施/系统属性
     *
     * @param facsCode 设施编码
     * @return 结果
     */
    int deleteEmsFacsAttrByFacsCode(String facsCode);
}
